/***************************************************
  This is our GFX example for the Adafruit ILI9341 Breakout and Shield
  ----> http://www.adafruit.com/products/1651
  TFT is 240 x 320 and is 2.2"

  Pin naming https://github.com/stm32duino/Arduino_Core_STM32/blob/master/variants/FEATHER_F405/variant.h
 ****************************************************/

#include <SPI.h>                 // include Arduino SPI library for TFT
#include <TFT_eSPI.h>            // Hardware-specific library
//#include "Adafruit_GFX.h"      // include Adafruit graphics library
//#include "Adafruit_ILI9341.h"  // include Adafruit ILI9340/41 TFT display driver
//#include <Fonts/FreeSerifBold18pt7b.h> // Font for TFT
#include "Free_Fonts.h" // Include the header file attached to this sketch
#include <Adafruit_BME280.h>     // include Adafruit BME280 sensor library
#include <Adafruit_DS3502.h>     // include Adafruit DS3502 digital potentiometer driver

//#define TFT_DC 9 //PB8
//#define TFT_CS 10 //PB9
// Use hardware SPI and the above for CS/DC
//Adafruit_ILI9341 tft = Adafruit_ILI9341(TFT_CS, TFT_DC);
TFT_eSPI tft = TFT_eSPI(); //Pins defined in User_Setup.h

#define BME280_I2C_ADDRESS  0x76
Adafruit_BME280  bme280;  // initialize Adafruit BME280 library

Adafruit_DS3502 ds3502 = Adafruit_DS3502();

#define WIPER_VALUE_PIN A1 // DS3502 wiper pin
#define LED_CHAIN_PIN PB0 //A0 // Resistor string from LEDs
int ledV = 0; // Vol
int VDD = 0; // Use this to measure the 3.3V rail


void setup() {
  Serial.begin(115200);
  // Wait until serial port is opened
 // while (!Serial) {
  //  delay(1);
  //}
  Serial.println("Start her up!");
  analogReadResolution(12); // 0-4095 STM32 has 12-bit ADC

  if (!ds3502.begin()) {
    Serial.println("Couldn't find DS3502 chip");
    //while (1);
  }
  else {
  Serial.println("Found DS3502 chip");
  ds3502.setWiperDefault(0); // Start up with LED chain off
  }

  tft.begin(); // Pass in a higher SPI frequency, 48000000
  tft.setRotation(1);
  tft.fillScreen(TFT_BLACK); //Adafruit uses ILI9341_BLACK

  // initialize the BME280 sensor
  if ( bme280.begin(BME280_I2C_ADDRESS) == 0 )
  { // connection error or device address wrong!
    tft.setCursor(0, 0);
    tft.setTextColor(TFT_RED);
    tft.println("Where's the BME280 Sensor??!!");
    Serial.println("Couldn't find BME280 chip");
    //while(1);                 // stay here
  }

  
  tft.setTextColor(TFT_GREEN);
  //tft.setFont(&FreeSerifBold18pt7b);
  //tft.setTextDatum(L_BASELINE);
  //tft.setTextFont(FONT6);
  tft.setFreeFont(&FreeSerifBold18pt7b);
  tft.setCursor(5, 30);
  tft.println("Temp");
  tft.println("Humidity");
  tft.println("Pressure");
  tft.println("A0 Voltage");
  tft.println("A4 Voltage");
  // Now setup the tft for printing the values
  tft.setTextColor(TFT_WHITE, TFT_BLACK); // ~14 pixels tall

}

void loop(void) {

  int ledVoltage;

  // Read LED Chain
  ledV = analogRead(LED_CHAIN_PIN);
  Serial.print("A0 Count is: ");
  Serial.println(ledV);
  ledVoltage = ledV * 3300UL / 4095; //Value in mv
  Serial.print("A0 Voltage is: ");
  Serial.println(ledVoltage / 1000.0, 3);

  VDD = analogRead(A4);
  Serial.print("A4 Count is: ");
  Serial.println(VDD);

  //Now let's correct for read voltage on the 3.3V rail
  ledVoltage = (ledV * 3300UL / 4095) * (VDD / 4095.0); //Value in mv
  Serial.print("Corrected A0 Voltage is: ");
  Serial.println(ledVoltage / 1000.0, 3);

  // Convert temperature to Fahrenheit
  Serial.print("Temperature = ");
  Serial.print(bme280.readTemperature() * 9 / 5 + 32);
  Serial.println(" *F");

  Serial.print("Pressure = ");
  Serial.print(bme280.readPressure() / 3386.39);
  Serial.println("inHg");

  Serial.print("Humidity = ");
  Serial.print(bme280.readHumidity());
  Serial.println(" %");
  Serial.println("");

  Serial.print("Digital Pot Currently Set at: ");
  Serial.println(ds3502.getWiper());

  // Set the digital pot, just shift right by 5 (2^12 >> 4 = 2^7
  ds3502.setWiper(ledV >>5);

  // Need to black out data areas before writing new values
 // tft.fillRect(185, 0, 135, 240, TFT_BLACK); //Upper Left Corner XY, Width, Height, Color

  // Add data to the screen
  //tft.setCursor(185, 30);
  //tft.print(bme280.readTemperature() * 9 / 5.0 + 32);
  tft.drawString(String(bme280.readTemperature() * 9 / 5.0 + 32), 185, 30, GFXFF);
  // print degree symbol ( ° )
 // tft.drawCircle(270, 10, 3, TFT_WHITE); // xcenter, ycenter, radius, WHITE
//  tft.print(" F");
//  tft.setCursor(185, 72); //
//  tft.print(bme280.readHumidity());
  tft.drawString(String(bme280.readHumidity()), 185, 72, GFXFF);
 // tft.print(" %");
 // tft.setCursor(185, 114); //
 // tft.print(bme280.readPressure() / 3386.39);
  tft.drawString(String(bme280.readPressure() / 3386.39), 185, 114, GFXFF);
 // tft.print(" in");
 // tft.setCursor(185, 156); //
 // tft.print(ledVoltage / 1000.0, 3);
   tft.drawString(String(ledVoltage / 1000.0, 3), 185, 156, GFXFF);
  //tft.print(" V");

  delay(5000);
}
